#include <bits/stdc++.h>
#include "testlib.h"
#define ff first
#define ss second
#define szof(_x) ((int) (_x).size())

using namespace std;
typedef long long ll;
typedef pair<int, int> pii;
const int INF = 1e9 + 7;
const ll INFL = 1e18 + 123;
const double PI = atan2(0, -1);

struct point {
	int x, y;

	point(int _x, int _y) : x(_x), y(_y) {}

	point operator+(point const& other) const {
		return point(x + other.x, y + other.y);
	}

	point operator-(point const& other) const {
		return point(x - other.x, y - other.y);
	}

	point operator-() const {
		return point(-x, -y);
	}

	double len() const {
		return sqrt((ll) x * x + (ll) y * y);
	}

	ll len2() const {
		return (ll) x * x + (ll) y * y;
	}

	bool operator<(point const& other) const {
		return x < other.x || (x == other.x && y < other.y);
	}

	bool operator==(point const& other) const {
		return x == other.x && y == other.y;
	}

	bool operator!=(point const& other) const {
		return x != other.x || y != other.y;
	}
};

ostream& operator<<(ostream& o, point const& p) {
	// o << "(" << p.x << ", " << p.y << ")";
	o << p.x << " " << p.y;
	return o;
}

ostream& operator<<(ostream& o, vector<point> const& poly) {
	cerr << "Polygon\n";
	for (auto& p : poly) {
		cerr << p << endl;
	}
	cerr << "...";
	return o;
}

ll cross(point const& p1, point const& p2) {
	return (ll) p1.x * p2.y - (ll) p1.y * p2.x;
}

ll scalar(point const& p1, point const& p2) {
	return (ll) p1.x * p2.x + (ll) p1.y * p2.y;
}

bool cmp(point const& p1, point const& p2) {
	ll tmp = cross(p1, p2);
	if (tmp) {
		return tmp > 0;
	}
	return p1.len2() < p2.len2();
}

vector<point> convex_hull(vector<point> arr) {
	int mem = 0;
	for (int i = 0; i < szof(arr); ++i) {
		if (arr[i] < arr[mem]) {
			mem = i;
		}
	}
	point center = arr[mem];
	vector<point> ret;
	for (auto& p : arr) {
		if (p != center) {
			ret.push_back(p - center);
		}
	}
	swap(ret, arr);
	ret = {point(0, 0)};
	sort(arr.begin(), arr.end(), cmp);
	for (auto& p : arr) {
		while (szof(ret) >= 2) {
			auto& a = ret[szof(ret) - 2];
			auto& b = ret.back();
			if (cross(b - a, p - b) <= 0) {
				ret.pop_back();
			} else {
				break;
			}
		}
		ret.push_back(p);
	}
	for (auto& p : ret) {
		p = p + center;
	}
	return ret;
}

bool cmp2(point const& p1, point const& p2) {
	bool fl1 = p1.x < 0 || (p1.x == 0 && p1.y < 0);
	bool fl2 = p2.x < 0 || (p2.x == 0 && p2.y < 0);
	if (fl1 != fl2) {
		return fl1 < fl2;
	}
	return cross(p1, p2) > 0;
}

bool intersects(vector<point> const& poly1, vector<point> poly2) {
	vector<point> segs;
	int mem1 = 0;
	for (int i = 0; i < szof(poly1); ++i) {
		int next = (i + 1) % szof(poly1);
		segs.push_back(poly1[next] - poly1[i]);
		if (poly1[i] < poly1[mem1]) {
			mem1 = i;
		}
	}
	for (auto& p : poly2) {
		p = -p;
	}
	// reverse(poly2.begin(), poly2.end());
	int mem2 = 0;
	for (int i = 0; i < szof(poly2); ++i) {
		int next = (i + 1) % szof(poly2);
		segs.push_back(poly2[next] - poly2[i]);
		if (poly2[i] < poly2[mem2]) {
			mem2 = i;
		}
	}
	sort(segs.begin(), segs.end(), cmp2);
	vector<point> res;
	res.push_back(poly1[mem1] + poly2[mem2]);
	for (auto v : segs) {
		if (cross(v, point(0, 0) - res.back()) < 0) {
			return false;
		}
		res.push_back(res.back() + v);
	}
	res.pop_back();
	return true;
}

double sqr(double num) {
	return num * num;
}

typedef pair<double, double> pdd;

int main(int argc, char* argv[]) {
	registerGen(argc, argv, 1);

	int n = atoi(argv[1]);
	int k = atoi(argv[2]);
	int maxc = atoi(argv[3]);

	while (true) {
		set<point> have;
		for (int i = 0; i < k; ++i) {
			int x, y;
			while (true) {
				x = rnd.next(-maxc, maxc);
				y = rnd.next(-maxc, maxc);
				if (!have.count(point(x, y))) {
					have.insert(point(x, y));
					break;
				}
			}
		}

		vector<pdd> centers;
		for (int i = 0; i < n; ++i) {
			centers.emplace_back(rnd.next(-maxc, maxc), rnd.next(-maxc, maxc));
		}

		vector<point> points(have.begin(), have.end());

		vector<int> where(k);
		for (int i = 0; i < 5; ++i) {
			for (int j = 0; j < k; ++j) {
				double best = 1e100;
				for (int q = 0; q < n; ++q) {
					double val = sqrt(sqr(centers[q].ff - points[j].x) + sqr(centers[q].ss - points[j].y));
					if (best > val) {
						best = val;
						where[j] = q;
					}
				}
			}

			vector<int> cnt(n);
			fill(centers.begin(), centers.end(), make_pair(0, 0));
			for (int j = 0; j < k; ++j) {
				centers[where[j]].ff += points[j].x;
				centers[where[j]].ss += points[j].y;
				++cnt[where[j]];
			}
			for (int j = 0; j < n; ++j) {
				centers[j].ff /= cnt[j];
				centers[j].ss /= cnt[j];
			}
		}

		vector<vector<point>> polys(n);
		for (int i = 0; i < k; ++i) {
			polys[where[i]].push_back(points[i]);
		}

		bool ok = true;
		for (int i = 0; i < n; ++i) {
			if (szof(polys[i]) < 3) {
				ok = false;
				break;
			}
			polys[i] = convex_hull(polys[i]);
			if (szof(polys[i]) < 3) {
				ok = false;
				break;
			}
		}

		if (!ok) {
			continue;
		}

		int a = rnd.next(0, n - 1);
		int b = rnd.next(0, n - 1);
		cout << n << " " << a + 1 << " " << b + 1 << "\n";
		for (int i = 0; i < n; ++i) {
			cout << szof(polys[i]) << "\n";
			rotate(polys[i].begin(), polys[i].begin() + rnd.next(0, szof(polys[i]) - 1), polys[i].end());
			for (auto p : polys[i]) {
				cout << p.x << " " << p.y << "\n";
			}

			// cerr << "Polygon\n";
			// for (auto p : polys[i]) {
			// 	cerr << p.x << " " << p.y << endl;
			// }
			// cerr << "...\n";
		}
		break;
	}

	return 0;
}